BoxDict

Struct BoxDict 

pub struct BoxDict<'a>(/* private fields */);
This is a runtime generated, owned Dict with string slices out of some backing store. These slices may come from a Vec<String>, or else from slices out of a single String.

Implementations

Source

impl<'a> BoxDict<'a>

pub fn from_lines(s: &'a str) -> Self

Construct a dictionary from a single string slice, taking each non-empty line, with leading and trailing whitespace trimmed, as a single word.

pub fn from_sep(s: &'a str, sep: &str) -> Self

Construct a dictionary from a single string slice, with fields separated by a separator. Individual words are not trimmed.