RefDict

Struct RefDict 

pub struct RefDict<'a>(/* private fields */);
This type provides a Dict over non-owned data. It may be used in tests, or to implement a static compile-time dictionary, giving the compiler maximum freedom as to how to lay out the string slices.

Implementations

Source

impl<'a> RefDict<'a>

pub const unsafe fn new(words: &'a [&'a str], hash: &'a [u8; 32]) -> Self

Construct a dictionary from the given word slice and hash reference.

Safety

This function is only safe if hash is the BLAKE2b256 hash of the word list as if constructed via BoxDict::from_iter(words.into_iter()).