pub struct BoxDict<'a>(/* private fields */);Expand description
This is a runtime generated, owned Dict with string slices out of some backing store.
These slices may come from a Vec<String>, or else from slices out of a single String.
Implementations