pub struct RefDict<'a>(/* private fields */);Expand description
This type provides a Dict over non-owned data. It may be used in tests, or to implement a
static compile-time dictionary, giving the compiler maximum freedom as to how to lay out the
string slices.
Implementations